#ifndef NT2_INCLUDE_CONSTANTS_TWOTONMB_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWOTONMB_HPP_INCLUDED

#include <nt2/constant/include/constants/twotonmb.hpp>

#endif
